@@ -1,45 +1,51 @@
 import asyncio
+import importlib
 import re
 import tempfile
-import warnings
-from importlib import import_module
 from logging import getLogger
 from pathlib import Path
 from time import time
-from typing import Union
 
 import math
-import orjson
+import ujson
 
-from cats.types import Json
+from cats.types import Bytes, Json
 
 __all__ = [
+    'to_uint',
+    'as_uint',
     'Delay',
     'require',
     'tmp_file',
     'int2hex',
     'bytes2hex',
     'format_amount',
-    'enable_stream_debug',
     'filter_json',
 ]
 
 logging = getLogger('CATS.utils')
 
 
+def to_uint(number: int, length: int = None) -> bytes:
+    if length is None:
+        length = (number.bit_length() + 7) // 8
+    return number.to_bytes(length, byteorder='big', signed=False)
+
+
+def as_uint(data: bytes) -> int:
+    return int.from_bytes(data, byteorder='big', signed=False)
+
+
 class Delay:
+    """
+    Rate-limiter, that calls asyncio.sleep(N), each time an object called.
+    N is calculated based on specified speed, size of latest chunk and ∆time
+    """
+
     def __init__(self, speed: int = 0):
-        self.speed = speed
-        self.start = time()
-        self.sent = 0
-
-    def __enter__(self):
-        self.start = time()
-        self.sent = 0
-        return self
-
-    def __exit__(self, exc_type, exc_val, exc_tb):
-        ...
+        self.speed: int = speed
+        self.start: float = time()
+        self.sent: float = 0.0
 
     async def __call__(self, length: int = 0):
         if not self.speed:
@@ -47,13 +53,18 @@ class Delay:
 
         went = time() - self.start + 0.01
         self.start = time()
-        self.sent = max(0, length + self.sent - self.speed * went)
+        self.sent = max(0.0, length + self.sent - self.speed * went)
         if not self.sent:
             return
         await asyncio.sleep(self.sent / self.speed)
 
 
 def tmp_file(**kwargs) -> Path:
+    """
+    Creates NamedTemporaryFile and returns associated pathlib.Path
+    :param kwargs: NamedTemporaryFile arguments
+    :return: pathlib.Path(temp_file)
+    """
     kwargs['delete'] = kwargs.get('delete', False)
     return Path(tempfile.NamedTemporaryFile(**kwargs).name)
 
@@ -62,6 +73,10 @@ def require(dotted_path: str, /, *, strict: bool = True):
     """
     Import a dotted module path and return the attribute/class designated by the
     last name in the path. Raise ImportError if the import failed.
+
+    :param dotted_path: Path to attribute/class in module
+    :param strict: should the error be thrown
+    :return: attribute/class
     """
     try:
         try:
@@ -69,7 +84,7 @@ def require(dotted_path: str, /, *, strict: bool = True):
         except ValueError as err:
             raise ImportError(f"{dotted_path} doesn't look like a module path") from err
 
-        module = import_module(module_path)
+        module = importlib.import_module(module_path)
 
         try:
             return getattr(module, class_name)
@@ -83,12 +98,18 @@ def require(dotted_path: str, /, *, strict: bool = True):
 
 
 def int2hex(number: int, chars: int = 2) -> str:
+    """
+    Converts integers to human-readable HEX
+    :param number: integer to convert
+    :param chars: minimal amount of chars(bytes) to show
+    :return: HEX string w/o prefix
+    """
     a = hex(number)[2:].upper()
     chars = max(len(a) // 2, chars)
     return ('00' * chars + a)[-chars * 2:]
 
 
-def bytes2hex(buffer: Union[bytes, bytearray, memoryview], *, separator: str = ' ', prefix: bool = False) -> str:
+def bytes2hex(buffer: Bytes, *, separator: str = ' ', prefix: bool = False) -> str:
     """
     Converts byte-like to HEX string
 
@@ -98,7 +119,7 @@ def bytes2hex(buffer: Union[bytes, bytearray, memoryview], *, separator: str = '
     :return: HEX style string
     :raise TypeError:
     """
-    if not isinstance(buffer, (bytes, bytearray, memoryview)):
+    if not isinstance(buffer, Bytes):
         raise TypeError(f'Invalid buffer type = {type(buffer)}')
 
     hexadecimal = buffer.hex().upper()
@@ -146,57 +167,25 @@ def format_amount(num: int, *, base: int = 1024, prefix: str = '', suffix: str =
     return f'{sign}{val}{["", "K", "M", "G", "T", "P", "E", "Z"][magnitude]}{prefix}{suffix}'
 
 
-def enable_stream_debug():
-    warnings.warn("enable_stream_debug will be deprecated in version 4.0. "
-                  "Use Server(debug=True) or Connection(debug=True) instead", PendingDeprecationWarning)
-    from tornado.iostream import IOStream
-    rb = IOStream.read_bytes
-    ru = IOStream.read_until
-    wr = IOStream.write
-
-    async def read_bytes(self: IOStream, num_bytes, partial: bool = False):
-        chunk = await rb(self, num_bytes, partial=partial)
-        peer = self.socket.getpeername() if self.socket else ('0.0.0.0', 0)
-        logging.info(f'[RECV {peer}] {bytes2hex(chunk)}')
-        return chunk
-
-    async def read_until(self: IOStream, delimiter: bytes, max_bytes: int = None):
-        chunk = await ru(self, delimiter, max_bytes=max_bytes)
-        peer = self.socket.getpeername() if self.socket else ('0.0.0.0', 0)
-        logging.info(f'[RECV {peer}] {bytes2hex(chunk)}')
-        return chunk
-
-    async def write(self: IOStream, data):
-        peer = self.socket.getpeername() if self.socket else ('0.0.0.0', 0)
-        logging.info(f'[SEND {peer}] {bytes2hex(data)}')
-        return await wr(self, data)
-
-    IOStream.read_until = read_until
-    IOStream.read_bytes = read_bytes
-    IOStream.write = write
-
-
 _HIDE = re.compile(r'.*(password|key|secret|jwt|pwd|пароль|ключ|секрет).*', re.IGNORECASE | re.UNICODE)
 
 
-def filter_json(json: Json, max_len: int = 16, max_size: int = 64, indent: bool = False) -> str:
-    option = 0
-    if indent:
-        option |= orjson.OPT_INDENT_2
-    if isinstance(json, (bytes, bytearray, memoryview)):
-        json = orjson.loads(json)
-    return orjson.dumps(f_json(json, max_len, max_size), option=option).decode('utf-8')
+def filter_json(json: Json | Bytes, max_len: int = 16, max_size: int = 64, indent: bool = False) -> str:
+    if isinstance(json, Bytes):
+        json = ujson.loads(json)
+    result = _filter_json_part(json, max_len, max_size)
+    return ujson.dumps(result, ensure_ascii=False, escape_forward_slashes=False, indent=2 if indent else 0)
 
 
-def f_json(json: Json, max_len: int = 16, max_size: int = 64) -> Json:
+def _filter_json_part(json: Json, max_len: int = 16, max_size: int = 64) -> Json:
     if isinstance(json, dict):
         return {
-            k: '<masked>' if _HIDE.match(k) else f_json(v, max_len, max_size)
+            k: '<masked>' if _HIDE.match(k) else _filter_json_part(v, max_len, max_size)
             for k, v in (*tuple(json.items())[:max_size], ('<more>', f'{len(json) - max_len} items'))[:len(json)]
         }
     if isinstance(json, list):
         return [
-            f_json(v, max_len, max_size)
+            _filter_json_part(v, max_len, max_size)
             for v in (*json[:max_size], f'{len(json) - max_len} more')[:len(json)]
         ]
     if isinstance(json, str) and len(json) > max_len:
